# Marketplace Agreements API

> see https://aka.ms/autorest

The underlying APIs are available to users who would like to write their own REST calls. These APIs would allow the user to accept the terms at a subscription, offer and SKU level. These apis are invoked in the context of azure subscription.

----
***GetAzureRmMarketplaceTerms***

**Request**

This api returns the latest terms for a given Subscription, Publisher, Product and Name.

**Reply**

200 OK. Agreement Terms in response body.

***SaveAzureRmMarketplaceTerms***

**Request**

This api sends the license information retrieved by the first API along with Accepted flag which confirms that the terms are accepted(true) or not accepted(false).

**Reply**

1. 200 OK. The request was successfully processed and the terms were accepted or acceptance revoked as per the request body.
2. 400 Bad/Malformed request. E.g. Signature doesn’t match, please retrieve terms again and request acceptance.
3. 403 Forbidden. E.g. The caller does not have permission to accept terms for given subscription. (only a reader).
4. 404 E.g. The Publisher/Offer/Plan tuple is not a valid virtual machine.

---
## Getting Started
To build the SDK for Marketplace Agreements, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`
---

## Configuration



### Basic Information
These are the global settings for the Marketplace Agreements API.

``` yaml
openapi-type: arm
tag: package-2015-06-01
```


### Tag: package-2015-06-01

These settings apply only when `--tag=package-2015-06-01` is specified on the command line.

``` yaml $(tag) == 'package-2015-06-01'
input-file:
- Microsoft.MarketplaceOrdering/stable/2015-06-01/Agreements.json
```


---
# Code Generation


## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-python
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-node
  - repo: azure-sdk-for-ruby
    after_scripts:
      - bundle install && rake arm:regen_all_profiles['azure_mgmt_marketplace_ordering']
```


## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  namespace: Microsoft.Azure.Management.MarketplaceOrdering
  output-folder: $(csharp-sdks-folder)/Management.MarketplaceOrdering/Generated
  clear-output-folder: true
```


## Python

These settings apply only when `--python` is specified on the command line.
Please also specify `--python-sdks-folder=<path to the root directory of your azure-sdk-for-python clone>`.
Use `--python-mode=update` if you already have a setup.py and just want to update the code itself.

``` yaml $(python)
python-mode: create
python:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  payload-flattening-threshold: 2
  namespace: azure.mgmt.marketplaceordering
  package-name: azure-mgmt-marketplaceordering
  clear-output-folder: true
  package-version: 0.1.0
```
``` yaml $(python) && $(python-mode) == 'update'
python:
  no-namespace-folders: true
  output-folder: $(python-sdks-folder)/azure-mgmt-marketplaceordering/azure/mgmt/marketplaceordering
```
``` yaml $(python) && $(python-mode) == 'create'
python:
  basic-setup-py: true
  output-folder: $(python-sdks-folder)/azure-mgmt-marketplaceordering
```

Workaround invalid date-time returned by the server.

``` yaml $(python)
directive:
  - from: swagger-document
    where: $.definitions.AgreementProperties.properties.retrieveDatetime
    transform: delete $.format
```

## Node.js

``` yaml $(nodejs)
directive:
  - from: swagger-document
    where: $.definitions.AgreementProperties.properties.retrieveDatetime
    transform: delete $.format
```

## TypeScript

``` yaml $(typescript)
directive:
  - from: swagger-document
    where: $.definitions.AgreementProperties.properties.retrieveDatetime
    transform: delete $.format
```

## Go

These settings apply only when `--go` is specified on the command line.

``` yaml $(go)
go:
  license-header: MICROSOFT_APACHE_NO_VERSION
  namespace: marketplaceordering
  clear-output-folder: true
```

### Go multi-api

``` yaml $(go) && $(multiapi)
batch:
  - tag: package-2015-06-01
```

### Tag: package-2015-06-01 and go

These settings apply only when `--tag=package-2015-06-01 --go` is specified on the command line.
Please also specify `--go-sdk-folder=<path to the root directory of your azure-sdk-for-go clone>`.

``` yaml $(tag) == 'package-2015-06-01' && $(go)
output-folder: $(go-sdk-folder)/services/marketplaceordering/mgmt/2015-06-01/marketplaceordering
```


## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
azure-arm: true
fluent: true
namespace: com.microsoft.azure.management.marketplaceordering
license-header: MICROSOFT_MIT_NO_CODEGEN
payload-flattening-threshold: 1
output-folder: $(azure-libraries-for-java-folder)/azure-mgmt-marketplaceordering
```

### Java multi-api

``` yaml $(java) && $(multiapi)
batch:
  - tag: package-2015-06-01
```

### Tag: package-2015-06-01 and java

These settings apply only when `--tag=package-2015-06-01 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2015-06-01' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.marketplaceagreementsapi.v2015_06_01
  output-folder: $(azure-libraries-for-java-folder)/marketplaceagreementsapi/resource-manager/v2015_06_01
regenerate-manager: true
generate-interface: true
```


